﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace WpfMapOnSphere
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private WpfMap m_wpfMap = new WpfMap();

        public MainWindow()
        {
            InitializeComponent();
            earthViewport3D.Geometry = SphereMesh.Create(20, 20, 0.75);
            gridTexture.Children.Add(m_wpfMap);
        }

        private void DisplayMap()
        {
            m_wpfMap.MapTools.PanZoomBar.Visibility = System.Windows.Visibility.Collapsed;
            m_wpfMap.MapTools.Logo.Visibility = System.Windows.Visibility.Collapsed;
            m_wpfMap.ExtentOverlay.PanMode = MapPanMode.Disabled;
            //            m_wpfMap.ExtentOverlay = null;

            // Set the Map Unit. The reason for setting it to DecimalDegrees is that is what the shapefile’s unit of measure is inherently in.
            m_wpfMap.MapUnit = GeographyUnit.DecimalDegree;

            // We create a new Layer and pass the path to a Shapefile into its constructor. 
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"C:\Program Files (x86)\ThinkGeo\Map Suite Wpf Desktop Evaluation Edition 5.0\Samples\CSharp Samples\SampleData\Data\Countries02.shp");

            // Set the worldLayer with a preset Style, as AreaStyles.Country1 has YellowGreen background and black border, our worldLayer will have the same render style.  
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;

            // This setting will apply from ZoonLevel01 to ZoomLevel20, that means we can see the world the same style with ZoomLevel01 all the time no matter how far we zoom out/in. 
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Create a new Layer Overlay to hold the layer we just created
            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.TileHeight = 512;
            layerOverlay.TileWidth = 512;

            // Add a background Layer
            layerOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)));
            // Add the shapefile layer to the layer overlay
            layerOverlay.Layers.Add(worldLayer);

            // We need to add the layerOverlay to map.
            m_wpfMap.Overlays.Add(layerOverlay);

            // Set a proper extent for the Map.  
            m_wpfMap.CurrentExtent = new RectangleShape(new PointShape(-180, 90), new PointShape(180, -90));

            // We now need to call the Refresh() method of the Map control so that the Map can redraw based on the data that has been provided.
            m_wpfMap.Refresh();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            DisplayMap();
        }
    }
}
